//=============================================================================
// STM32F4 Demo (Olimex H407) 
//=============================================================================

#include "stm32f4xx.h"

#define LED_PORT        GPIOC
#define LED_GREEN       GPIO_Pin_13

// Needed for the Pin Configuration
GPIO_InitTypeDef GPIO_InitStructure;

// Called by the Systick Interrupt Handler
void TimingDelay_Decrement(void);

void Delay(__IO uint32_t nTime);

static __IO uint32_t TimingDelay;
volatile uint32_t GlobalTimer = 0;

//=============================================================================
// Main
//=============================================================================

int main(void)
{
  uint32_t sec = 0;

  if (SysTick_Config(SystemCoreClock / 1000)) {
     /* Capture error */
     while (1) {
         ;
     }
  }

  /* Enable GPIO Clock */
  RCC_AHB1PeriphClockCmd(RCC_AHB1Periph_GPIOC, ENABLE);

  /* Set LED PIO as output. */
  GPIO_InitStructure.GPIO_Pin = LED_GREEN;
  GPIO_InitStructure.GPIO_OType = GPIO_OType_PP;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_25MHz;
  GPIO_InitStructure.GPIO_PuPd = GPIO_PuPd_NOPULL;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_OUT;
  GPIO_Init(LED_PORT, &GPIO_InitStructure);

  // ============================================================
  // while()
  // ============================================================

  while (1)
  {

    LED_PORT->BSRRL = LED_GREEN;
    // Per Lib: GPIO_SetBits(LED_PORT,LED_GREEN)
    Delay(1000);

    LED_PORT->BSRRH = LED_GREEN;
    // Per Lib: GPIO_ResetBits(LED_PORT,LED_GREEN)
    Delay(1000);

    // Oder in einem 1s Block
    // if (GlobalTimer > (sec + 1000))
    // {
    //     sec = GlobalTimer;
    //     // Toggle Heartbeat LED
    //     // --------------------
    //     LED_PORT->ODR ^= LED_GREEN;
    //     // Per Lib: GPIO_ToggleBits(LED_PORT,LED_GREEN);
    // }
  }
}

//===========================================================
// Inserts a delay time.
// nTime: specifies the delay time length, in milliseconds.
//===========================================================

void Delay(__IO uint32_t nTime) {
    TimingDelay = nTime;

    while (TimingDelay != 0)
        ;
}

//===========================================================
// Systick function
//===========================================================

void TimingDelay_Decrement(void) {
    if (TimingDelay != 0x00) {
        TimingDelay--;
    }
	GlobalTimer++;
}

//===========================================================
// Needed by a function in the STM-Lib
//===========================================================

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  while (1)
  {}
}

#endif

